@@ -1,5 +1,6 @@
 use ::lazy_static::lazy_static;
 use std::borrow::Borrow;
+use std::collections::HashSet;
 use std::fmt::{Debug, Display, Formatter};
 use std::ops::DerefMut;
 
@@ -89,6 +90,10 @@ impl Cell {
         IntoIter { next: self }
     }
 
+    pub fn collect_vec(&self) -> Vec<&Cell> {
+        self.iter().collect::<Vec<_>>()
+    }
+
     pub fn is_nil(&self) -> bool {
         matches!(self, Cell::Nil)
     }
@@ -101,6 +106,115 @@ impl Cell {
         matches!(self, Cell::Symbol(_))
     }
 
+    pub fn is_list(&self) -> bool {
+        if self.is_pair() {
+            let mut rest = self.cdr().unwrap();
+            loop {
+                if !rest.is_pair() {
+                    return rest.is_nil();
+                } else {
+                    rest = rest.cdr().unwrap();
+                }
+            }
+        } else {
+            false
+        }
+    }
+
+    pub fn is_quote(&self) -> bool {
+        self.is_symbol_str("quote")
+    }
+
+    pub fn is_lambda(&self) -> bool {
+        self.is_symbol_str("lambda")
+    }
+
+    pub fn is_symbol_str(&self, s: &'static str) -> bool {
+        match self.as_symbol() {
+            Some(sym) => sym == s,
+            _ => false,
+        }
+    }
+
+    /// Is Primitive Symbol
+    ///
+    /// Return true if the given cell is a primitive symbol (e.g. a built-in
+    /// procedure)
+    ///
+    /// # Arguments
+    /// `cell`
+    pub fn is_primitive_symbol(&self) -> bool {
+        lazy_static! {
+            static ref PRIMITIVE_SYMBOLS: HashSet<&'static str> = HashSet::from([
+                "car",
+                "cdr",
+                "cons",
+                "define",
+                "eq?",
+                "eqv?",
+                "lambda",
+                "quote",
+                "+",
+                "-",
+                "*",
+                "if",
+                "not",
+                "boolean?",
+                "char?",
+                "list?",
+                "null?",
+                "pair?",
+                "port?",
+                "procedure?",
+                "string?",
+                "symbol?",
+                "vector?"
+            ]);
+        }
+        match self {
+            Cell::Symbol(sym) => {
+                PRIMITIVE_SYMBOLS.contains(sym.as_str()) || self.is_syntactic_keyword()
+            }
+            _ => false,
+        }
+    }
+
+    /// Is Syntactic Keyword
+    ///
+    /// Return true if the given cell is a syntactic keyword.
+    ///
+    /// # Arguments
+    /// `cell`
+    pub fn is_syntactic_keyword(&self) -> bool {
+        lazy_static! {
+            static ref PRIMITIVE_SYMBOLS: HashSet<&'static str> = HashSet::from([
+                "begin!",
+                "case",
+                "define",
+                "delay",
+                "do",
+                "else",
+                "lambda",
+                "if",
+                "cond",
+                "and",
+                "or",
+                "let",
+                "let*",
+                "letrec",
+                "quasiquote",
+                "quote",
+                "unquote",
+                "unquote-splicnig",
+                "set!",
+            ]);
+        }
+        match self {
+            Cell::Symbol(sym) => PRIMITIVE_SYMBOLS.contains(sym.as_str()),
+            _ => false,
+        }
+    }
+
     pub fn car(&self) -> Option<&Cell> {
         match self {
             Cell::Pair(car, _) => Some(car),
@@ -377,9 +491,15 @@ mod tests {
         assert_eq!(list!["foo"], Cell::new_list(vec!(Cell::new_symbol("foo"))));
     }
 
+    #[test]
+    fn proper_list() {
+        assert!(list![1, 2, 3].is_list());
+    }
+
     #[test]
     fn improper_list() {
         let improper_list = Cell::new_improper_list(vec![cell![1], cell![2]].into_iter(), cell![3]);
+        assert!(!improper_list.is_list());
         assert_eq!(improper_list, cons!(cell!(1), cons!(cell!(2), cell!(3))));
         assert_eq!(format!("{}", improper_list), "(1 2 . 3)");
     }
