@@ -2,7 +2,6 @@ use crate::cell::Cell;
 use crate::vm::lambda::Lambda;
 use crate::vm::vcell::VCell;
 use crate::vm::Error;
-use lazy_static::lazy_static;
 use std::cell::RefCell;
 use std::collections::{HashMap, HashSet};
 
@@ -362,7 +361,7 @@ fn find_free_symbols_in_proc<'a>(
         find_free_symbols(car, env, free)?;
     }
 
-    let mut lat = match car {
+    let mut rest = match car {
         Cell::Symbol(sym) => match sym.as_str() {
             "define" => cdr
                 .cdr()
@@ -391,55 +390,19 @@ fn find_free_symbols_in_proc<'a>(
         _ => cdr,
     };
 
-    while lat.is_pair() {
-        find_free_symbols(lat.car().unwrap(), env, free)?;
-        lat = lat.cdr().unwrap();
+    while rest.is_pair() {
+        find_free_symbols(rest.car().unwrap(), env, free)?;
+        rest = rest.cdr().unwrap();
     }
 
     // improper list
-    if !lat.is_nil() {
-        find_free_symbols(lat, env, free)?;
+    if !rest.is_nil() {
+        find_free_symbols(rest, env, free)?;
     }
 
     Ok(())
 }
 
-impl Cell {
-    pub fn is_quote(&self) -> bool {
-        self.is_symbol_str("quote")
-    }
-
-    pub fn is_lambda(&self) -> bool {
-        self.is_symbol_str("lambda")
-    }
-
-    pub fn is_symbol_str(&self, s: &'static str) -> bool {
-        match self.as_symbol() {
-            Some(sym) => sym == s,
-            _ => false,
-        }
-    }
-
-    /// Is Primitive Symbol
-    ///
-    /// Return true if the given cell is a primitive symbol (e.g. a built-in
-    /// procedure)
-    ///
-    /// # Arguments
-    /// `cell`
-    pub fn is_primitive_symbol(&self) -> bool {
-        lazy_static! {
-            static ref PRIMITIVE_SYMBOLS: HashSet<&'static str> = HashSet::from([
-                "car", "cdr", "cons", "define", "eq?", "eqv?", "lambda", "quote", "+", "-", "*"
-            ]);
-        }
-        match self {
-            Cell::Symbol(sym) => PRIMITIVE_SYMBOLS.contains(sym.as_str()),
-            _ => false,
-        }
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
